==> mx-packageinstaller-pkglist_18.12.06.tar.xz: mx-packageinstaller-pkglist/dropbox.pm <==
<?xml version="1.0"?>
<app>

<category>
Network
</category>

<name>
Dropbox
</name>

<description>
   <am>Dropbox file sync utility</am>
   <ca>Utilitat de sincronització de fitxers amb Dropbox</ca>
   <cs>Dropbox file sync utility</cs>
   <da>Dropbox file sync utility</da>
   <de>Dropbox Dateisynchronisationsprogramm</de>
   <el>Βοηθητικό πρόγραμμα συγχρονισμού αρχείων Dropbox</el>
   <en>Dropbox file sync utility</en>
   <es>Sincronizar archivos con Dropbox</es>
   <fi>Dropbox file sync utility</fi>
   <fr>Utilitaire de synchronisation de fichier Dropbox</fr>
   <hi>Dropbox file sync utility</hi>
   <hr>Dropbox file sync utility</hr>
   <hu>Dropbox file sync utility</hu>
   <is>Dropbox file sync utility</is>
   <it>Utility di sincronizzazione dei file</it>
   <ja>Dropbox file sync utility</ja>
   <kk>Dropbox file sync utility</kk>
   <lt>Dropbox failų sinchronizavimo paslaugų programa</lt>
   <nl>Dropbox bestand synchronisatie gereedschap</nl>
   <pl>Dropbox file sync utility</pl>
   <pt_BR>Dropbox file sync utility</pt_BR>
   <pt>Utilitário de armazenagem e sincronização de ficheiros</pt>
   <ro>Dropbox file sync utility</ro>
   <ru>Утилита синхронизации файлов с Dropbox</ru>
   <sk>Dropbox file sync utility</sk>
   <sq>Dropbox file sync utility</sq>
   <sv>Dropbox filsynkroniserings-redskap</sv>
   <tr>Dropbox file sync utility</tr>
   <uk>Dropbox file sync utility</uk>
   <zh_TW>Dropbox file sync utility</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
nautilus-dropbox
python-gpgme
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
nautilus-dropbox
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.03.01.tar.xz: mx-packageinstaller-pkglist/dropbox.pm <==
<?xml version="1.0"?>
<app>

<category>
Network
</category>

<name>
Dropbox
</name>

<description>
   <am>Dropbox file sync utility</am>
   <ar>Dropbox file sync utility</ar>
   <bg>Dropbox file sync utility</bg>
   <ca>Utilitat de sincronització de fitxers amb Dropbox</ca>
   <cs>Dropbox file sync utility</cs>
   <da>Dropbox-filsynkroniseringsredskab</da>
   <de>Dropbox Dateisynchronisationsprogramm</de>
   <el>Βοηθητικό πρόγραμμα συγχρονισμού αρχείων Dropbox</el>
   <en>Dropbox file sync utility</en>
   <es>Sincronizar archivos con Dropbox</es>
   <et>Dropbox file sync utility</et>
   <eu>Dropbox file sync utility</eu>
   <fa>Dropbox file sync utility</fa>
   <fi>Dropbox file sync utility</fi>
   <fr>Utilitaire de synchronisation de fichier Dropbox</fr>
   <he_IL>Dropbox file sync utility</he_IL>
   <hi>Dropbox file sync utility</hi>
   <hr>Dropbox file sync utility</hr>
   <hu>Dropbox file sync utility</hu>
   <id>Dropbox file sync utility</id>
   <is>Dropbox file sync utility</is>
   <it>Utility di sincronizzazione dei file</it>
   <ja_JP>Dropbox file sync utility</ja_JP>
   <ja>Dropbox file sync utility</ja>
   <kk>Dropbox file sync utility</kk>
   <ko>Dropbox file sync utility</ko>
   <lt>Dropbox failų sinchronizavimo paslaugų programa</lt>
   <mk>Dropbox file sync utility</mk>
   <nb>Dropbox file sync utility</nb>
   <nl>Dropbox bestand synchronisatie gereedschap</nl>
   <pl>Dropbox file sync utility</pl>
   <pt_BR>Dropbox file sync utility</pt_BR>
   <pt>Utilitário de armazenagem e sincronização de ficheiros</pt>
   <ro>Dropbox file sync utility</ro>
   <ru>Утилита синхронизации файлов с Dropbox</ru>
   <sk>Dropbox file sync utility</sk>
   <sl>Dropbox file sync utility</sl>
   <sq>Dropbox file sync utility</sq>
   <sr>Dropbox file sync utility</sr>
   <sv>Dropbox filsynkroniserings-redskap</sv>
   <tr>Dropbox file sync utility</tr>
   <uk>утиліта синхронізації файлів Dropbox</uk>
   <zh_CN>Dropbox file sync utility</zh_CN>
   <zh_TW>Dropbox file sync utility</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
nautilus-dropbox
python-gpgme
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
nautilus-dropbox
</uninstall_package_names>
</app>
